import "../declarations/global";
import IUnityConfig from "../interfaces/unity-config";
import UnityComponent from "../components/unity";
import IUnityContextEventMap from "../interfaces/unity-context-event-map";
/**
 * The Unity Context.
 */
export default class UnityContext {
    unityConfig: IUnityConfig;
    /**
     * A reference to the Unity Component binded to this unityContext.
     * @type {UnityComponent}
     */
    private unityComponentReference?;
    /**
     * A reference to the Unity Instance binded to this unityContext.
     * @type {UnityInstance}
     */
    private unityInstance?;
    /**
     * A list of the UnityEvents binded to this unityContext.
     * @type {IUnityEvent[]}
     */
    private unityEvents;
    /**
     * Creates a new instance of the Unity context model.
     * @param {IUnityConfig} unityConfig The Unity config used to build the player.
     */
    constructor(unityConfig: IUnityConfig);
    /**
     * Sets the reference to the UnityComponent.
     * @param {UnityComponent} unityComponentReference the target unity component.
     */
    setComponentReference(unityComponentReference: UnityComponent): void;
    /**
     * Sets the reference of the UnityInstance.
     * @param {UnityInstance} unityInstance the target unityInstance.
     */
    setUnityInstance(unityInstance: UnityInstance): void;
    /**
     * Quits the Unity Instance and clears it from memory.
     */
    quitUnityInstance(): void;
    /**
     * Sends a message to the UnityInstance to invoke a public method.
     * @param {string} gameObjectName the name of the game object in your Unity scene.
     * @param {string} methodName the name of the public method on the game object.
     * @param {string | number | boolean} parameter an optional method parameter.
     */
    send(gameObjectName: string, methodName: string, parameter?: string | number | boolean): void;
    /**
     * Registers an event listener for the Unity player. These can be
     * system events like when the player is initialized or loader and
     * your custom events from Unity.
     * @param {string} eventName the event name
     * @param {Function} eventListener the event function
     * @returns {any} The Function
     *
     */
    on<MapKey extends keyof IUnityContextEventMap | (string & {})>(eventName: keyof IUnityContextEventMap | (MapKey & {}), eventListener: (parameter: MapKey extends keyof IUnityContextEventMap ? IUnityContextEventMap[MapKey] : any) => void): void;
    /**
     * Invokes an event listener that has been registered using the on function.
     * @param {string} eventName the event name
     * @param {Function} eventValue the event value
     */
    invokeEventListener(eventName: string, eventValue?: any): void;
    /**
     * Enables or disabled the fullscreen mode of the UnityInstance.
     * @param {boolean} enabled
     */
    setFullscreen(enabled: boolean): void;
}
//# sourceMappingURL=unity-context.d.ts.map